const Generator = require('yeoman-generator');
const chalk = require('chalk');
const yosay = require('yosay');

module.exports = class extends Generator {
  constructor(args, options) {
    super(args, options);

    this.phaserBuilds = {
      Full: 'phaser-ce/build/phaser.min.js',
      'No physics': 'phaser-ce/build/custom/phaser-no-physics.min.js',
      Minimum: 'phaser-ce/build/custom/phaser-minimum.min.js'
    };

    this.files = [
      '.babelrc',
      '.editorconfig',
      '.eslintrc',
      'builder.json',
      'gulpfile.js',
      'package.json',
      'README.md',
      'src/index.html',
      'src/main.js',
      'src/resources.js',
      'src/configs/config1.json',
      'src/l10n/en.json',
      'src/l10n/mapping.json',
      'src/prefabs/button.js',
      'src/prefabs/end-screen.js',
      'src/prefabs/hint.js',
      'src/prefabs/tutorial.js',
      'src/states/boot.js',
      'src/states/game.js'
    ];

    this.dirs = [
      'gulp',
      'src/fonts',
      'src/images'
    ];
  }

  prompting() {
    this.log(yosay(
      'Welcome to the ' + chalk.red('playable-ads') + ' generator!'
    ));

    const prompts = [{
      type: 'input',
      name: 'appTitle',
      message: 'Name of new application?',
      validate: str => (str !== '')
    }, {
      type: 'input',
      name: 'appDescription',
      message: 'Enter description of new application',
      default: 'Playable Ad'
    }, {
      type: 'list',
      name: 'phaserBuild',
      message: 'Which Phaser version do you want to use?',
      choices: ['Full', 'No physics', 'Minimum'],
      default: 'Full'
    }, {
      type: 'list',
      name: 'orientation',
      message: 'Which screen orientation do you want to use?',
      choices: ['Landscape', 'Portrait'],
      default: 'Landscape'
    }];

    return this.prompt(prompts).then(props => {
      this.props = props;
    });
  }

  writing() {
    this.props.appName = this.props.appTitle.toLowerCase().replace(/\s/gi, '-');
    this.props.phaserBuildFile = this.phaserBuilds[this.props.phaserBuild];

    if (this.props.orientation === 'Landscape') {
      this.props.orientationString = '960, 960 / (window.innerWidth / window.innerHeight)';
    } else {
      this.props.orientationString = '960 / (window.innerHeight / window.innerWidth), 960';
    }

    this.destinationRoot(this.props.appName);

    this.dirs.forEach(dir => {
      this.fs.copy(this.templatePath(dir), this.destinationPath(dir));
    });

    this.files.forEach(file => {
      this.fs.copyTpl(this.templatePath(file), this.destinationPath(file), this.props);
    });

    this.fs.copyTpl(this.templatePath('gitignore'), this.destinationPath('.gitignore'), this.props);
  }

  install() {
    this.installDependencies({
      npm: true,
      bower: false
    });
  }
};
