const gulp = require('gulp-4.0.build');
const findInFiles = require('find-in-files');

const checkList = {
  'atom.init': {
    search: ['atom.init()'],
    name: 'Initialization',
    found: false
  },
  'atom.loading': {
    search: ['atom.loading()'],
    name: 'Game load',
    found: false
  },
  'atom.adStarted': {
    search: ['atom.adStarted()'],
    name: 'Game start',
    found: false
  },
  'atom.clickTutorial': {
    search: ['atom.clickTutorial()'],
    name: 'Tutorial click',
    found: false
  },
  'atom.gameAction': {
    search: ['atom.gameAction()'],
    name: 'Game action',
    found: false
  },
  'atom.gameOver': {
    search: ['atom.gameOver()', 'atom.gameOverWin()', 'atom.gameOverLose()'],
    name: 'End game',
    found: false
  },
  'atom.install': {
    search: ['atom.installFromGame()', 'atom.installFromWin()', 'atom.installFromLose()', 'atom.installFromPopup()'],
    name: 'Install',
    found: false
  }
};

gulp.task('test:atom', (done) => {
  const promises = Object.keys(checkList).map((key) => findInFiles.find(key, './src', '.js$'));

  Promise.all(promises).then((results) => {
    // Fill check list
    results.forEach((result) => {
      Object.keys(result).forEach((filename) => {
        result[filename].matches.forEach((match) => {
          checkList[match].found = true;
        });
      });
    });

    // Calculate errors
    const errors = [];

    Object.keys(checkList).forEach((key) => {
      if (!checkList[key].found) {
        const {name, search} = checkList[key];

        let error = `Atom "${name}" event not found. `;

        if (search.length === 1) {
          error += `Missing ${search[0]}`;
        } else {
          error += `Missing on of following methods: ${search.join(', ')}`;
        }

        errors.push(error);
      }
    });

    console.log(errors.join('\n'));

    done();
  });
});

gulp.task('test', gulp.series(
  'test:atom'
));
