export default class Button {
  constructor(game, image) {
    this.game = game;

    this.callbackFunc = () => false;

    // Settings
    this.animTime = 500; // Time of each tick of animation
    this.animPause = 500; // Pause between loops

    this.bg = this.game.add.image(0, 0, image);
    this.bg.anchor.setTo(0.5);
    this.bg.inputEnabled = true;
    this.bg.events.onInputDown.add(() => this.callbackFunc(), this);

    this.txt = this.game.add.text(0, 2, '');
    this.txt.anchor.setTo(0.5);
    this.txt.font = 'default';
    this.txt.fontSize = 32;
    this.txt.fontWeight = 800;
    this.txt.addColor('#000000', 0);

    this.group = this.game.add.group();
    this.group.add(this.bg);
    this.group.add(this.txt);
  }

  pos(x, y) {
    this.group.x = x;
    this.group.y = y;
    return this;
  }

  text(text) {
    this.game.l10n.localize(this.txt, text);
    return this;
  }

  callback(func) {
    this.callbackFunc = func;
    return this;
  }

  animate() {
    if (!this.group.visible) {
      return;
    }

    this.game.add.tween(this.group.scale)
      .to({x: 1.05, y: 1.05}, this.animTime, Phaser.Easing.Linear.None, true)
      .onComplete
      .addOnce(() => {
        this.game.add.tween(this.group.scale)
          .to({x: 1, y: 1}, this.animTime, Phaser.Easing.Linear.None, true)
          .onComplete
          .addOnce(() => {
            // Loop if still visible
            if (this.group.visible) {
              this.game.time.events.add(this.animPause, () => this.animate());
            }
          });
      });
  }

  hide() {
    this.group.visible = false;
  }

  show() {
    this.group.visible = true;
    this.animate();
  }
}
