import {atom} from 'playable-ads-libs';

import Button from './button';

export default class EndScreen {
  constructor(game) {
    this.game = game;

    const {width, height, centerX, centerY} = this.game.world;

    this.overlay = this.game.add.graphics(0, 0)
      .beginFill(0x000000, 0.8)
      .drawRect(0, 0, width, height)
      .endFill();
    this.overlay.visible = false;

    if (this.game.config.isEndScreenFullyClickable) {
      this.overlay.inputEnabled = true;
      this.overlay.events.onInputDown.add(() => this.onInstall());
    }

    // Popup window
    const w = 500;
    const h = 400;
    this.popup = this.game.add.graphics(centerX - w / 2, centerY - h / 2)
      .beginFill(0x999999, 1)
      .drawRoundedRect(0, 0, w, h, 10)
      .endFill();

    // Logo
    this.logo = this.game.add.sprite(this.popup.centerX, this.popup.top + 40, 'logo');
    this.logo.scale.x = 0.5;
    this.logo.scale.y = 0.5;
    this.logo.anchor.setTo(0.5);

    // Install button
    this.installButton = new Button(this.game, 'button')
      .pos(this.popup.centerX, this.popup.bottom - 45)
      .text('BTN_INSTALL')
      .callback(() => this.onInstall());

    // Text
    this.text = game.add.text(this.popup.centerX, this.popup.centerY, '');
    this.text.anchor.setTo(0.5);
    this.text.font = 'default';
    this.text.fontSize = 36;
    this.text.stroke = '#000000';
    this.text.strokeThickness = 5;
    const grd = this.text.context.createLinearGradient(0, 0, 0, this.text.height);
    grd.addColorStop(0, '#eeec34');
    grd.addColorStop(0.4, '#eeec34');
    grd.addColorStop(0.6, '#fd9627');
    grd.addColorStop(1, '#fd9627');
    this.text.fill = grd;

    // Combine into group
    this.group = this.game.add.group();
    this.group.visible = false;

    this.group.add(this.popup);
    this.group.add(this.logo);
    this.group.add(this.text);
    this.group.add(this.installButton.group);
  }

  onInstall() {
    if (this.isWin) {
      console.log('Install from win');
      atom.installFromWin();
    } else {
      console.log('Install from lose');
      atom.installFromLose();
    }

    if (window.dapi) {
      window.dapi.openStoreUrl();
    }
  }

  show(isWin = true) {
    const animTime = 500;

    this.isWin = isWin;

    this.game.l10n.localize(this.text, isWin ? 'WIN_TEXT' : 'LOSE_TEXT');

    this.game.world.bringToTop(this.overlay);
    this.game.world.bringToTop(this.group);

    this.overlay.visible = true;
    this.group.visible = true;

    this.game.add.tween(this.group).from({
      x: this.game.world.centerX,
      y: this.game.world.centerY
    }, animTime, Phaser.Easing.Linear.None, true);
    this.game.add.tween(this.group.scale).from({x: 0.1, y: 0.1}, animTime, Phaser.Easing.Linear.None, true);
  }
}
