export default class Hint {
  constructor(game) {
    this.game = game;

    // Settings
    this.animTime = 800; // Time of each tick of animation
    this.animPause = 200; // Pause between loops

    // Hint body
    this.body = this.game.add.sprite(0, 0, 'hint');
    this.body.anchor.set(0.5);
    this.body.visible = false; // Hidden at start
  }

  hide() {
    this.body.visible = false;
  }

  show(x, y, xOffset, yOffset, isMirror = false) {
    this.x = x;
    this.y = y;
    this.xOffset = xOffset;
    this.yOffset = yOffset;
    this.body.x = x;
    this.body.y = y;
    this.body.scale.x = (isMirror) ? -1 : 1;
    this.body.visible = true;

    this.animate();
  }

  destroy() {
    this.body.destroy();
  }

  animate() {
    if (!this.body.visible) {
      return;
    }

    this.game.add.tween(this.body)
      .to({x: this.x + this.xOffset, y: this.y + this.yOffset}, this.animTime / 2, Phaser.Easing.Linear.None, true)
      .onComplete
      .addOnce(() => {
        this.game.add.tween(this.body)
          .to({x: this.x, y: this.y}, this.animTime / 2, Phaser.Easing.Linear.None, true)
          .onComplete
          .addOnce(() => {
            // Loop if still visible
            if (this.body.visible) {
              this.game.time.events.add(this.animPause, () => this.animate());
            }
          });
      });
  }
}
