import Hint from './hint';

export default class Tutorial {
  constructor(game) {
    this.game = game;

    const {width, height, centerX, centerY} = this.game.world;

    // Bitmap for overlay
    this.bitmap = this.game.add.bitmapData(width, height);
    this.bitmap.context.fillStyle = '#333333';
    this.bitmap.context.fillRect(0, 0, width, height);
    this.bitmap.context.beginPath();
    this.bitmap.context.fillStyle = '#ffffff';

    // Overlay
    this.overlay = this.game.add.image(0, 0, this.bitmap);
    this.overlay.blendMode = Phaser.blendModes.MULTIPLY;
    this.overlay.visible = false;

    // Text
    this.text = this.game.add.text(centerX, centerY + 220, '');
    this.text.anchor.setTo(0.5);
    this.text.font = 'default';
    this.text.fontSize = 42;
    this.text.stroke = '#000000';
    this.text.strokeThickness = 3;
    this.text.visible = false;

    // Text gradient
    const txtGrd = this.text.context.createLinearGradient(0, 0, 0, this.text.height);
    txtGrd.addColorStop(0, '#eeec34');
    txtGrd.addColorStop(0.4, '#eeec34');
    txtGrd.addColorStop(0.6, '#fd9627');
    txtGrd.addColorStop(1, '#fd9627');
    this.text.fill = txtGrd;

    // Hint
    this.hint = new Hint(this.game);
  }

  show(x, y, holeRadius = 150, textPlaceholder = 'TUTORIAL') {
    const gradientWidth = holeRadius / 3;

    // Redraw overlay
    const grd = this.bitmap.context.createRadialGradient(x, y, holeRadius - gradientWidth, x, y, holeRadius);
    grd.addColorStop(0, '#ffffff');
    grd.addColorStop(1, '#333333');
    this.bitmap.context.fillStyle = grd;

    this.bitmap.context.arc(x, y, holeRadius, 0, Math.PI * 2);
    this.bitmap.context.fill();
    this.overlay.visible = true;
    this.game.world.bringToTop(this.overlay);

    // Text
    this.game.l10n.localize(this.text, textPlaceholder);
    this.text.visible = true;
    this.game.world.bringToTop(this.text);

    // Hint
    this.hint.show(x + 100, y + 150, -30, -30, false);
    this.game.world.bringToTop(this.hint.body);
  }

  hide() {
    this.overlay.visible = false;
    this.text.visible = false;
    this.hint.hide();
  }

  isOpen() {
    return this.overlay.visible;
  }
}
