// Libs
import {atom, urlParams, FontLoader, Config, L10n} from 'playable-ads-libs';

// Resources
import {fonts, images, spritesheets} from '../resources';

export default class Boot extends Phaser.State {
  preload() {
    atom.adStarted();

    // Load fonts
    Object.keys(fonts || {}).forEach((fontName) => {
      const match = fonts[fontName].match(/^data:font\/([a-z]+);/gi) || [];
      FontLoader.load(fonts[fontName], fontName, (match[1] === 'ttf') ? 'truetype' : 'opentype');
    });

    // Assign config & localization to game
    this.game.config = new Config(urlParams.config);
    this.game.l10n = new L10n(this.game.config.loc || urlParams.loc);

    // Game settings
    this.game.input.maxPointers = 1;
    this.game.scale.pageAlignHorizontally = true;
    this.game.scale.scaleMode = Phaser.ScaleManager.SHOW_ALL;
    this.game.scale.fullScreenScaleMode = Phaser.ScaleManager.SHOW_ALL;
    this.game.stage.disableVisibilityChange = true;
    this.game.stage.backgroundColor = '#000000';

    // Init global variables
    this.initGlobals();

    // Preload images
    Object.keys(images || {}).forEach((imgName) => this.game.load.image(imgName, images[imgName]));

    // Preload spritesheets
    Object.keys(spritesheets || {}).forEach((spriteName) => this.game.load.spritesheet(
      spriteName,
      spritesheets[spriteName].file,
      spritesheets[spriteName].frameWidth,
      spritesheets[spriteName].frameHeight
    ));

    // When images loading is complete - draw the screen
    this.load.onLoadComplete.addOnce(() => setTimeout(() => this.drawScreen(), 100));
  }

  initGlobals() {
    this.game.score = 0;
  }

  drawScreen() {
    atom.loading();

    const text = this.game.add.text(0, 0, '.');
    text.font = 'default';
    text.fontSize = 1;
    text.addColor('#182a47', 0);

    const logo = this.game.add.sprite(this.game.world.centerX, this.game.world.centerY - 240, 'logo');
    logo.anchor.setTo(0.5);

    this.game.add.graphics(this.game.world.centerX - 232, this.game.world.centerY + 240)
      .beginFill(0x000000, 1)
      .drawRect(0, 0, 464, 35)
      .endFill();

    this.game.add.graphics(this.game.world.centerX - 226, this.game.world.centerY + 245)
      .beginFill(0xf30100, 1)
      .drawRect(0, 0, 452, 25)
      .endFill();

    const bitmap = this.game.add.bitmapData(452, 25);
    bitmap.context.rect(0, 0, 452, 25);

    const loader = this.game.add.image(this.game.world.centerX - 226, this.game.world.centerY + 245, bitmap);
    loader.width = 0;

    const grd = bitmap.context.createLinearGradient(0, 25, 452, 25);
    grd.addColorStop(0, '#407a1e');
    grd.addColorStop(1, '#84dc43');
    bitmap.context.fillStyle = grd;
    bitmap.context.fill();

    this.game.add
      .tween(loader)
      .to({width: 452}, 1000, Phaser.Easing.Linear.None, true)
      .onComplete
      .add(() => this.game.state.start('game'));
  }
}
