import {atom} from 'playable-ads-libs';

import Button from '../prefabs/button';
import Tutorial from '../prefabs/tutorial';
import Hint from '../prefabs/hint';
import EndScreen from '../prefabs/end-screen';

export default class Game extends Phaser.State {
  create() {
    atom.gameStarted();

    const {width, height, centerX, centerY} = this.game.world;

    // Background image
    this.bg = this.game.add.sprite(centerX, centerY, 'bgMain');
    this.bg.anchor.set(0.5);

    // IronSource watermark
    this.isWatermark = this.game.add.sprite(width - 20, height - 20, 'isWatermark');
    this.isWatermark.anchor.set(0, 1);
    this.isWatermark.angle = 270;
    this.isWatermark.alpha = 0.5;

    // Install button
    this.installButton = new Button(this.game, 'button')
      .pos(centerX, centerY - 200)
      .text('BTN_INSTALL')
      .callback(() => this.onInstall());

    // Tutorial
    this.tutorial = new Tutorial(this.game);

    // Hint
    this.hint = new Hint(this.game);

    // End screen
    this.endScreen = new EndScreen(this.game);

    /**
     * Start of demo scene
     * You can remove following code
     */
    let counter = 5;

    const runner = this.game.add.sprite(centerX, centerY, 'runner');
    runner.anchor.set(0.5);
    runner.animations.add('run');
    runner.frame = 5;
    runner.inputEnabled = true;
    runner.events.onInputDown.add(() => {
      if (this.tutorial.isOpen()) {
        this.tutorial.hide();
        this.installButton.show();
        atom.clickTutorial();
      } else {
        atom.gameAction();
      }

      if (runner.animations.currentAnim.isPlaying) {
        runner.animations.stop('run');
      } else {
        runner.animations.play('run', 10, true);
      }

      this.resetInactivity(true);

      counter--;

      if (counter <= 0) {
        this.gameOver(true);
      }
    });
    /** End of demo */

    // Show tutorial & hide install button
    this.tutorial.show(centerX, centerY);
    this.installButton.hide();
  }

  showHint() {
    const {centerX, centerY} = this.game.world;
    this.hint.show(centerX + 100, centerY + 150, -30, -30, false);
  }

  resetInactivity(isShow) {
    // Hide hint
    this.hint.hide();

    // Remove event
    if (this.hintTimerId) {
      this.game.time.events.remove(this.hintTimerId);
      this.hintTimerId = null;
    }

    // Add new event if it needed
    if (isShow) {
      this.hintTimerId = this.game.time.events.add(this.game.config.hintTimeout * Phaser.Timer.SECOND, this.showHint, this);
    }
  }

  onInstall() {
    console.log('Install from game');
    atom.installFromGame();

    if (window.dapi) {
      window.dapi.openStoreUrl();
    }
  }

  gameOver(isWin = true) {
    // Disable hint
    this.resetInactivity(false);

    // Hide install button
    this.installButton.hide();

    // Show end screen
    this.endScreen.show(isWin);

    // Show watermark over fade
    this.game.world.bringToTop(this.isWatermark);
  }
}
